@@ -1,7 +1,7 @@
 import pytest
 pytest.importorskip('zmq')
 
-from partd.zmq import Server, keys_to_flush, log, File, Client
+from partd.zmq import Server, keys_to_flush, File, Client
 from partd import core, Dict
 from threading import Thread
 from time import sleep
